NEW_ADDR blocks are purely in-memory preallocated blocks, and thus
equivalent to what the core FS code calls delayed allocations, and not
unwritten extents which do have on-disk blocks allocated from which
reads always return zeroes until they are converted to written status.

Signed-off-by: Christoph Hellwig <h...@lst.de>
---
 fs/f2fs/data.c | 8 ++++----
 fs/f2fs/f2fs.h | 4 ++--
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/fs/f2fs/f2fs.h b/fs/f2fs/f2fs.h
index db2dc3fa73162b..709bfd1c7c409e 100644
--- a/fs/f2fs/f2fs.h
+++ b/fs/f2fs/f2fs.h
@@ -647,9 +647,9 @@ struct extent_tree {
  */
 #define F2FS_MAP_NEW           (1U << 0)
 #define F2FS_MAP_MAPPED                (1U << 1)
-#define F2FS_MAP_UNWRITTEN     (1U << 2)
+#define F2FS_MAP_DELALLOC      (1U << 2)
 #define F2FS_MAP_FLAGS         (F2FS_MAP_NEW | F2FS_MAP_MAPPED |\
-                               F2FS_MAP_UNWRITTEN)
+                               F2FS_MAP_DELALLOC)
 
 struct f2fs_map_blocks {
        struct block_device *m_bdev;    /* for multi-device dio */
diff --git a/fs/f2fs/data.c b/fs/f2fs/data.c
index 541d625d94be42..444865e0cb6397 100644
--- a/fs/f2fs/data.c
+++ b/fs/f2fs/data.c
@@ -1638,9 +1638,9 @@ int f2fs_map_blocks(struct inode *inode, struct 
f2fs_map_blocks *map,
                bidx = f2fs_target_device_index(sbi, blkaddr);
 
        if (map->m_len == 0) {
                /* preallocated unwritten block should be mapped for fiemap. */
                if (blkaddr == NEW_ADDR)
-                       map->m_flags |= F2FS_MAP_UNWRITTEN;
+                       map->m_flags |= F2FS_MAP_DELALLOC;
                map->m_flags |= F2FS_MAP_MAPPED;
 
                map->m_pblk = blkaddr;
@@ -1962,7 +1962,7 @@ int f2fs_fiemap(struct inode *inode, struct 
fiemap_extent_info *fieinfo,
 
        compr_appended = false;
        /* In a case of compressed cluster, append this to the last extent */
-       if (compr_cluster && ((map.m_flags & F2FS_MAP_UNWRITTEN) ||
+       if (compr_cluster && ((map.m_flags & F2FS_MAP_DELALLOC) ||
                        !(map.m_flags & F2FS_MAP_FLAGS))) {
                compr_appended = true;
                goto skip_fill;
@@ -2008,7 +2008,7 @@ int f2fs_fiemap(struct inode *inode, struct 
fiemap_extent_info *fieinfo,
                                compr_cluster = false;
                                size += blks_to_bytes(inode, 1);
                        }
-               } else if (map.m_flags & F2FS_MAP_UNWRITTEN) {
+               } else if (map.m_flags & F2FS_MAP_DELALLOC) {
                        flags = FIEMAP_EXTENT_UNWRITTEN;
                }
 
@@ -1638,9 +1638,9 @@ int f2fs_map_blocks(struct inode *inode, struct 
 
        if (map->m_len == 0) {
-               /* preallocated unwritten block should be mapped for fiemap. */
+               /* reserved delalloc block should be mapped for fiemap. */
                if (blkaddr == NEW_ADDR)
-- 
2.30.2



_______________________________________________
Linux-f2fs-devel mailing list
Linux-f2fs-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/linux-f2fs-devel

Reply via email to